@@ -6,7 +6,6 @@ import subprocess
 import sys
 from os.path import dirname, normcase
 from pathlib import Path
-from shlex import quote
 from subprocess import Popen
 
 import pytest
@@ -15,7 +14,7 @@ from virtualenv.run import cli_run
 
 
 class ActivationTester:
-    def __init__(self, of_class, session, cmd, activate_script, extension) -> None:  # noqa: PLR0913
+    def __init__(self, of_class, session, cmd, activate_script, extension) -> None:
         self.of_class = of_class
         self._creator = session.creator
         self._version_cmd = [cmd, "--version"]
@@ -41,13 +40,13 @@ class ActivationTester:
                     encoding="utf-8",
                 )
                 out, err = process.communicate()
-            except Exception as exception:  # noqa: BLE001
+            except Exception as exception:
                 self._version = exception
                 if raise_on_fail:
                     raise
                 return RuntimeError(f"{self} is not available due {exception}")
             else:
-                result = out if out else err
+                result = out or err
                 self._version = result
                 return result
         return self._version
@@ -78,7 +77,8 @@ class ActivationTester:
         try:
             process = Popen(invoke, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, env=env)
             raw_, _ = process.communicate()
-            raw = raw_.decode()
+            raw = raw_.decode(errors="replace")
+            assert process.returncode == 0, raw
         except subprocess.CalledProcessError as exception:
             output = exception.output + exception.stderr
             assert not exception.returncode, output  # noqa: PT017
@@ -130,13 +130,13 @@ class ActivationTester:
         ]
 
     def assert_output(self, out, raw, tmp_path):
-        # pre-activation
+        """Compare _get_test_lines() with the expected values."""
         assert out[0], raw
         assert out[1] == "None", raw
         assert out[2] == "None", raw
-        # post-activation
-        expected = self._creator.exe.parent / os.path.basename(sys.executable)
-        assert self.norm_path(out[3]) == self.norm_path(expected), raw
+        # self.activate_call(activate_script) runs at this point
+        python_exe = self._creator.exe.parent / os.path.basename(sys.executable)
+        assert self.norm_path(out[3]) == self.norm_path(python_exe), raw
         assert self.norm_path(out[4]) == self.norm_path(self._creator.dest).replace("\\\\", "\\"), raw
         assert out[5] == self._creator.env_name
         # Some attempts to test the prompt output print more than 1 line.
@@ -153,7 +153,7 @@ class ActivationTester:
         assert out[-1] == "None", raw
 
     def quote(self, s):
-        return quote(s)
+        return self.of_class.quote(s)
 
     def python_cmd(self, cmd):
         return f"{os.path.basename(sys.executable)} -c {self.quote(cmd)}"
@@ -212,8 +212,8 @@ class RaiseOnNonSourceCall(ActivationTester):
             stderr=subprocess.PIPE,
             env=env,
         )
-        _out, _err = process.communicate()
-        err = _err.decode("utf-8")
+        _out, err_ = process.communicate()
+        err = err_.decode("utf-8")
         assert process.returncode
         assert self.non_source_fail_message in err
 
@@ -232,6 +232,7 @@ def raise_on_non_source_class():
 def activation_python(request, tmp_path_factory, special_char_name, current_fastest):
     dest = os.path.join(str(tmp_path_factory.mktemp("activation-tester-env")), special_char_name)
     cmd = ["--without-pip", dest, "--creator", current_fastest, "-vv", "--no-periodic-update"]
+    # `params` is accessed here. https://docs.pytest.org/en/stable/reference/reference.html#pytest-fixture
     if request.param:
         cmd += ["--prompt", special_char_name]
     session = cli_run(cmd)
@@ -240,7 +241,7 @@ def activation_python(request, tmp_path_factory, special_char_name, current_fast
     return session
 
 
-@pytest.fixture()
+@pytest.fixture
 def activation_tester(activation_python, monkeypatch, tmp_path, is_inside_ci):
     def _tester(tester_class):
         tester = tester_class(activation_python)
